#
#  Component	: 00snm_default.cds
#
#  Description	: Default mappings applied when translating 
#		  SunNet Manager Events into T/EC Events.
#
#  Primary Author : Marc Foret / IT Masters Inc.
#
#  (C) COPYRIGHT Tivoli Systems Inc., 1996
#  All Rights Reserved
#

#############################################################################
#                                                                           #
#  DEFAULT SLOT VALUES                                                      #
#                                                                           #
#############################################################################

MAP_DEFAULT
  source = SNM ;
  sub_source = NET ;
  hostname = $TARGET ;
  date = $REPORT_TIME ;
  adapter_host = $ADAPTER_HOST ;
END

#
#  Component	: 50snm_cbt.cds
#
#  Description	: Mappings applied when translating SunNet Manager 
#		  Events reporting SNMP traps defined in the Cabletron MIB
#		  into T/EC Events.
#
#  Primary Author : Marc Foret / IT Masters Inc.
#
#  (C) COPYRIGHT Tivoli Systems Inc., 1996
#  All Rights Reserved
#

#############################################################################
#                                                                           #
#  CABLETRON-SPECIFIC SNMP TRAPS                                            #
#                                                                           #
#############################################################################

CLASS Port_Segmenting_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "portSegmenting" ;
    3: ATTR(=,"boardIndex") ;
    4: ATTR(=,"portIndex") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    portIndex = $V4 ;
    sub_origin = PRINTF("%s.%s", $V3, $V4) ;
    msg = PRINTF("on port %s.%s", $V3, $V4) ;
END

# CLASS Port_Unsegmenting_CBT
# 'portUnsegmenting' traps are mapped to 'portSegmenting' CLOSED
CLASS Port_Segmenting_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "portUnsegmenting" ;
    3: ATTR(=,"boardIndex") ;
    4: ATTR(=,"portIndex") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    portIndex = $V4 ;
    sub_origin = PRINTF("%s.%s", $V3, $V4) ;
    msg = PRINTF("on port %s.%s", $V3, $V4) ;
    status = CLOSED ;
END

CLASS Port_Link_Down_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "portLinkDown" ;
    3: ATTR(=,"boardIndex") ;
    4: ATTR(=,"portIndex") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    portIndex = $V4 ;
    sub_origin = PRINTF("%s.%s", $V3, $V4) ;
    msg = PRINTF("on port %s.%s", $V3, $V4) ;
END

# CLASS Port_Link_Up_CBT
# 'portLinkUp' traps are mapped to 'portLinkDown' CLOSED
CLASS Port_Link_Down_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "portLinkUp" ;
    3: ATTR(=,"boardIndex") ;
    4: ATTR(=,"portIndex") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    portIndex = $V4 ;
    sub_origin = PRINTF("%s.%s", $V3, $V4) ;
    msg = PRINTF("on port %s.%s", $V3, $V4) ;
    status = CLOSED ;
END

CLASS Source_Address_New_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "newSourceAddress" ;
    3: ATTR(=,"boardIndex") ;
    4: ATTR(=,"portIndex") ;
    5: ATTR(=,"portSourceAddr") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    portIndex = $V4 ;
    portSourceAddr = $V5 ;
    sub_origin = PRINTF("%s.%s", $V3, $V4) ;
    msg = PRINTF("on port %s.%s: new Source Addr=%s", $V3, $V4, $V5) ;
END

CLASS Source_Address_Timeout_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "sourceAddressTimeout" ;
    3: ATTR(=,"boardIndex") ;
    4: ATTR(=,"portIndex") ;
    5: ATTR(=,"portSourceAddr") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    portIndex = $V4 ;
    portSourceAddr = $V5 ;
    sub_origin = PRINTF("%s.%s", $V3, $V4) ;
    msg = PRINTF("on %s.%s: mac addr %s", $V3, $V4, $V5) ;
END

CLASS Board_Removal_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "boardRemoval" ;
    3: ATTR(=,"boardIndex") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    sub_origin = PRINTF("%s", $V3) ;
    msg = PRINTF("Board %s removed", $V3) ;
END

CLASS Board_Insertion_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "boardInsertion" ;
    3: ATTR(=,"boardIndex") ;
    4: ATTR(=,"boardType") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    boardType = $V4 ;
    sub_origin = PRINTF("%s", $V3) ;
    msg = PRINTF("Board %s inserted", $V3) ;
END

CLASS Active_Port_In_Redundant_Circuit_Failed_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "activePortInRedundantCircuitFailed" ;
    3: ATTR(=,"boardIndex") ;
    4: ATTR(=,"portIndex") ;
    5: ATTR(=,"portRedundCrt") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    portIndex = $V4 ;
    portRedundCrt = $V5 ;
    sub_origin = PRINTF("%s.%s", $V3, $V4) ;
    msg = PRINTF("on port %s.%s: Redundant Circuit %s", $V3, $V4, $V5) ;
END

CLASS Redundant_Port_Activated_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "redundantPortActivated" ;
    3: ATTR(=,"boardIndex") ;
    4: ATTR(=,"portIndex") ;
    5: ATTR(=,"portRedundCrt") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    portIndex = $V4 ;
    portRedundCrt = $V5 ;
    sub_origin = PRINTF("%s.%s", $V3, $V4) ;
    msg = PRINTF("on port %s.%s: Redundant Circuit %s", $V3, $V4, $V5) ;
END

CLASS Redundant_Port_Test_Failed_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "redundantPortTestFailed" ;
    3: ATTR(=,"boardIndex") ;
    4: ATTR(=,"portIndex") ;
    5: ATTR(=,"portRedundCrt") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    portIndex = $V4 ;
    portRedundCrt = $V5 ;
    sub_origin = PRINTF("%s.%s", $V3, $V4) ;
    msg = PRINTF("on port %s.%s: Redundant Circuit %s", $V3, $V4, $V5) ;
END

CLASS Device_Traffic_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "deviceTrafficThresholdExceeded" ;
    3: ATTR(=,"devTrafficThreshold") ;
    4: ATTR(=,"deviceTimebase") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    devTrafficThreshold = $V3 ;
    deviceTimebase = $V4 ;
    msg = PRINTF("Threshold Exceeded = %s", $V3);
END

CLASS Device_Error_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "deviceErrorThresholdExceeded" ;
    3: ATTR(=,"devErrorThreshold") ;
    4: ATTR(=,"devErrorSource") ;
    5: ATTR(=,"deviceTimebase") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    devErrorThreshold = $V3 ;
    devErrorSource = $V4 ;
    deviceTimebase = $V5 ;
    msg = PRINTF("Error Threshold Exceeded = %s", $V3);
END

CLASS Device_Collision_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "deviceCollisionThresholdExceeded" ;
    3: ATTR(=,"devCollsThreshold") ;
    4: ATTR(=,"deviceTimebase") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    devCollsThreshold = $V3 ;
    deviceTimebase = $V4 ;
    msg = PRINTF("Collision Threshold Exceeded = %s", $V3);
END

CLASS Board_Traffic_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "boardTrafficThresholdExceeded" ;
    3: ATTR(=,"bdTrafficThreshold") ;
    4: ATTR(=,"deviceTimebase") ;
    5: ATTR(=,"boardIndex") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    bdTrafficThreshold = $V3 ;
    deviceTimebase = $V4 ;
    boardIndex = $V5 ;
    sub_origin = PRINTF("%s", $V5) ;
    msg = PRINTF("Board: %s: value= %s", $V5, $V3);
END

CLASS Board_Error_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "boardErrorThresholdExceeded" ;
    3: ATTR(=,"bdErrorThreshold") ;
    4: ATTR(=,"bdErrorSource") ;
    5: ATTR(=,"deviceTimebase") ;
    6: ATTR(=,"boardIndex") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    bdErrorThreshold = $V3 ;
    bdErrorSource = $V4 ;
    deviceTimebase = $V5 ;
    boardIndex = $V6 ;
    sub_origin = PRINTF("%s", $V6) ;
    msg = PRINTF ( "Board: %s: value= %s", $V6, $V3);
END

CLASS Board_Collision_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "boardCollisionThresholdExceeded" ;
    3: ATTR(=,"bdCollsThreshold") ;
    4: ATTR(=,"deviceTimebase") ;
    5: ATTR(=,"boardIndex") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    bdCollsThreshold = $V3 ;
    deviceTimebase = $V4 ;
    boardIndex = $V5 ;
    sub_origin = PRINTF("%s", $V5) ;
    msg = PRINTF ( "Board: %s: value= %s", $V5, $V3);
END

CLASS Port_Traffic_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "portTrafficThresholdExceeded" ;
    3: ATTR(=,"portTrafficThreshold") ;
    4: ATTR(=,"deviceTimebase") ;
    5: ATTR(=,"boardIndex") ;
    6: ATTR(=,"portIndex") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    portTrafficThreshold = $V3 ;
    deviceTimebase = $V4 ;
    boardIndex = $V5 ;
    portIndex = $V6 ;
    sub_origin = PRINTF("%s.%s", $V5, $V6) ;
    msg = PRINTF ( "Port: %s.%s: value= %s", $V5, $V6, $V3);
END

CLASS Port_Error_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "portErrorThresholdExceeded" ;
    3: ATTR(=,"portErrorThreshold") ;
    4: ATTR(=,"portErrorSource") ;
    5: ATTR(=,"deviceTimebase") ;
    6: ATTR(=,"boardIndex") ;
    7: ATTR(=,"portIndex") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    portErrorThreshold = $V3 ;
    portErrorSource = $V4 ;
    deviceTimebase = $V5 ;
    boardIndex = $V6 ;
    portIndex = $V7 ;
    sub_origin = PRINTF("%s.%s", $V6, $V7) ;
    msg = PRINTF ( "Port: %s.%s: value= %s", $V6, $V7, $V3);
END

CLASS Port_Collision_Threshold_Exceeded_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "portCollisionThresholdExceeded" ;
    3: ATTR(=,"portCollsThreshold") ;
    4: ATTR(=,"deviceTimebase") ;
    5: ATTR(=,"boardIndex") ;
    6: ATTR(=,"portIndex") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    portCollsThreshold = $V3 ;
    deviceTimebase = $V4 ;
    boardIndex = $V5 ;
    portIndex = $V6 ;
    sub_origin = PRINTF("%s.%s", $V5, $V6) ;
    msg = PRINTF ( "Port: %s.%s: value= %s", $V5, $V6, $V3);
END

CLASS Port_Type_Changed_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "portTypeChanged" ;
    3: ATTR(=,"boardIndex") ;
    4: ATTR(=,"portIndex") ;
    5: ATTR(=,"portTopologyType") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    portIndex = $V4 ;
    portTopologyType = $V5 ;
    sub_origin = PRINTF("%s.%s", $V3, $V4) ;
    msg = PRINTF ( "Port: %s.%s: type= %s", $V3, $V4, $V5);
END

CLASS Lock_Status_Changed_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "lockSTATUSChanged" ;
    3: ATTR(=,"deviceSrcAddrLocked") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    deviceSrcAddrLocked = $V3 ;
    msg = PRINTF ( "MacAddr: %s", $V3);
END

CLASS Port_Security_Violation_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "portSecurityViolation" ;
    3: ATTR(=,"boardIndex") ;
    4: ATTR(=,"portIndex") ;
    5: ATTR(=,"portSourceAddr") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    portIndex = $V4 ;
    portSourceAddr = $V5 ;
    sub_origin = PRINTF("%s.%s", $V3, $V4) ;
    msg = PRINTF("Port %s.%s: MacAddr %s", $V3, $V4, $V5) ;
END

CLASS Port_Violation_Reset_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "portViolationReset" ;
    3: ATTR(=,"boardIndex") ;
    4: ATTR(=,"portIndex") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    portIndex = $V4 ;
    sub_origin = PRINTF("%s.%s", $V3, $V4) ;
    msg = PRINTF("Port %s.%s", $V3, $V4) ;
END

# Class Env_Temp_Hot_CBT
# 'envTempHot' traps are mapped to 'envTemperature' OPEN/CRITICAL
CLASS ENV_TEMPERATURE_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "envTempHot" ;
    3: ATTR(=,"boardIndex") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    sub_origin = PRINTF("%s", $V3) ;
    severity = CRITICAL ;
END

# CLASS Env_Temp_Warm_CBT
# 'envTempWarm' traps are mapped to 'envTemperature' OPEN/WARNING
CLASS ENV_TEMPERATURE_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "envTempWarm" ;
    3: ATTR(=,"boardIndex") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    sub_origin = PRINTF("%s", $V3) ;
    severity = WARNING ;
END

# CLASS Env_Temp_Normal_CBT
# 'envTempNormal' traps are mapped to 'envTemperature' CLOSED
CLASS ENV_TEMPERATURE_CBT
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.52") ;
    2: $TRAP_TYPE = "envTempNormal" ;
    3: ATTR(=,"boardIndex") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    boardIndex = $V3 ;
    sub_origin = PRINTF("%s", $V3) ;
    status = CLOSED ;
END

#
#  Component	: 50snm_cisco.cds
#
#  Description	: Mappings applied when translating SunNet Manager 
#		  Events reporting SNMP traps defined in the Cisco MIB
#		  into T/EC Events.
#
#  Primary Author : Marc Foret / IT Masters Inc.
#
#  (C) COPYRIGHT Tivoli Systems Inc., 1996
#  All Rights Reserved
#

#############################################################################
#                                                                           #
#  CISCO-SPECIFIC SNMP TRAPS                                                #
#                                                                           #
#############################################################################

CLASS Cold_Start_Cisco
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE) , VALUE(PREFIX, "1.3.6.1.4.1.9") ;
    2: $TRAP_TYPE = "coldStart" ;
    3: ATTR(=,"whyReload") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    reason = $V3 ;
    msg = PRINTF("Reason: %s", $V3) ;
END

CLASS Link_Down_Cisco
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.9") ;
    2: $TRAP_TYPE = "linkDown" ;
    3: ATTR(=,"ifIndex") ;
    4: ATTR(=,"ifDescr") ;
    5: ATTR(=,"ifType") ;
    6: ATTR(=,"locIfReason") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    sub_origin = $V4 ;
    date = $TRAP_RECEIVE_TIME ;
    interface_index = $V3 ;
    interface_description = $V4 ;
    interface_type = $V5 ;
    reason = $V6 ;
    msg = PRINTF("IF %s down: %s", $V4, $V6) ;
END

# For Cisco routers, because we know the interface generating the trap,
# we map 'linkUp' traps to 'linkDown' CLOSED events
CLASS Link_Down_Cisco
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.9") ;
    2: $TRAP_TYPE = "linkUp" ;
    3: ATTR(=,"ifIndex") ;
    4: ATTR(=,"ifDescr") ;
    5: ATTR(=,"ifType") ;
    6: ATTR(=,"locIfReason") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    sub_origin = $V4 ;
    status = CLOSED ;
    date = $TRAP_RECEIVE_TIME ;
    interface_index = $V3 ;
    interface_description = $V4 ;
    interface_type = $V5 ;
    reason = $V6 ;
    msg = PRINTF("IF %s Up: %s", $V4, $V6) ;
END

CLASS Authentication_Failure_Cisco
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.9") ;
    2: $TRAP_TYPE = "authenticationFailure" ;
    3: ATTR(=,"authAddr") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($V3);
    3: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F3 ;
    date = $TRAP_RECEIVE_TIME ;
    originating_address = $V3 ;
    msg = PRINTF ("from %s", $F2) ;
END

CLASS EGP_Neighbor_Loss_Cisco
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.9") ;
    2: $TRAP_TYPE = "egpNeighborLoss" ;
    3: ATTR(=,"egpNeighAddr") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($V3);
    3: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F3 ;
    date = $TRAP_RECEIVE_TIME ;
    egp_neighbor_address = $V3 ;
    msg = PRINTF ("from EGP  %s", $F2) ;
END

CLASS Reload_Cisco
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.9") ;
    2: $TRAP_TYPE = "reload" ;
    3: ATTR(=,"whyReload") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    reason = $V3 ;
    msg = PRINTF("Reason: %s", $V3) ;
END

CLASS TCP_Connection_Close_Cisco
  SELECT
    1: ATTR(=,$TRAP_ENTERPRISE), VALUE(PREFIX, "1.3.6.1.4.1.9") ;
    2: $TRAP_TYPE = "tcpConnectionClose" ;
    3: ATTR(=,"tslineSesType") ;
    4: ATTR(=,"tcpConnState") ;
    5: ATTR(=,"loctcpConnElapsed") ;
    6: ATTR(=,"loctcpConnInBytes") ;
    7: ATTR(=,"loctcpConnOutBytes") ;
    8: ATTR(=,"tsLineUser") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    tslineSesType = $V3 ;
    tcpConnState = $V4 ;
    loctcpConnElapsed = $V5 ;
    loctcpConnInBytes = $V6 ;
    loctcpConnOutBytes = $V7 ;
    tsLineUser = $V8 ;
    msg = PRINTF("from %s", $V8);
END

#
#  Component	: 50snm_event.cds
#
#  Description	: Mappings applied when translating SunNet Manager 
#		  builtin Events into T/EC Events.
#
#  Primary Author : Marc Foret / IT Masters Inc.
#
#  (C) COPYRIGHT Tivoli Systems Inc., 1996
#  All Rights Reserved
#

#############################################################################
#                                                                           #
#  SNM DATABASE TRAPS                                                       #
#                                                                           #
#############################################################################

CLASS SNM_Node_Added
  SELECT
    1: $GROUP = "netmgt_db_config" ;
    2: ATTR(=,"created") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
#    adapter_host = $F2 ;
    agent_host = $F3 ;
    msg = PRINTF ("Node Add: %s", $V2);
    varbind_list = $VARBIND ;
END

CLASS SNM_Node_Deleted
  SELECT
    1: $GROUP = "netmgt_db_config" ;
    2: ATTR(=,"deleted") ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
#    adapter_host = $F2 ;
    agent_host = $F3 ;
    msg = PRINTF ("Node Deleted: %s", $V2);
    varbind_list = $VARBIND ;
END

#############################################################################
#                                                                           #
#  SNM 2.2 PREDEFINED EVENT REPORTS                                         #
#                                                                           #
#############################################################################

#
# Sample mapping for "if System Reboot" event report
# 
CLASS SNM_System_Reboot
  SELECT
    1: $AGENT_PROG = "hostperf" ;
    2: $GROUP = "data" ;
    3: ATTR(=,"uptime.+<"), VALUE(=, 78000) ;
    4: ATTR(=,"uptime");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG;
    group = $GROUP;
    resource = $N3;
    threshold = $V3;
    msg = PRINTF("uptime: %s%s (%s)", $N3, $V3, $V4);
    #varbind_list = $VARBIND ;
END

#
# Sample mapping for "when Disk is Full" event report
# 
CLASS SNM_Disk_Full
  SELECT
    1: $AGENT_PROG = "diskinfo" ;
    2: $GROUP = "diskSpace" ;
    3: ATTR(=,"capacity.>") ;
    4: ATTR(=,"capacity");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG;
    group = $GROUP;
    sub_origin = $K3;
    resource = $N3;
    threshold = $V3;
    msg = PRINTF("Capacity on %s > %s:  %s", $K3, $V3, $V4);
    capacity = $V4 ;
    #varbind_list = $VARBIND ;
END

CLASS SNM_Disk_Full
  SELECT
    1: $AGENT_PROG = "diskinfo" ;
    2: $GROUP = "diskSpace" ;
    3: ATTR(=,"capacity.>=") ;
    4: ATTR(=,"capacity");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG;
    group = $GROUP;
    sub_origin = $K3;
    resource = $N3;
    threshold = $V3;
    msg = PRINTF("Capacity on %s >= %s:  %s", $K3, $V3, $V4);
    capacity = $V4 ;
    #varbind_list = $VARBIND ;
END

CLASS SNM_Disk_Full
  SELECT
    1: $AGENT_PROG = "diskinfo" ;
    2: $GROUP = "diskSpace" ;
    3: ATTR(=,"capacity.<=") ;
    4: ATTR(=,"capacity");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG;
    group = $GROUP;
    sub_origin = $K3;
    resource = $N3;
    threshold = $V3;
    msg = PRINTF("Capacity on %s <= %s:  %s", $K3, $V3, $V4);
    status = "CLOSED" ;
    capacity = $V4 ;
    #varbind_list = $VARBIND ;
END

CLASS SNM_Disk_Full
  SELECT
    1: $AGENT_PROG = "diskinfo" ;
    2: $GROUP = "diskSpace" ;
    3: ATTR(=,"capacity.<") ;
    4: ATTR(=,"capacity");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG;
    group = $GROUP;
    sub_origin = $K3;
    resource = $N3;
    threshold = $V3;
    msg = PRINTF("Capacity on %s < %s:  %s", $K3, $V3, $V4);
    status = "CLOSED" ;
    capacity = $V4 ;
    #varbind_list = $VARBIND ;
END

#
# Sample mapping for "when Printer Error" event report
#
CLASS SNM_Printer_Error
  SELECT
    1: $AGENT_PROG = "lpstat" ;
    2: $GROUP = "status" ;
    3: ATTR(=,"statusCode.=="), VALUE(=, 3) ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG;
    group = $GROUP;
    resource = $N3;
    threshold = $V3;
    msg = "Printer Error";
END

CLASS SNM_Printer_Error
  SELECT
    1: $AGENT_PROG = "lpstat" ;
    2: $GROUP = "status" ;
    3: ATTR(=,"statusCode.!="), VALUE(=, 3) ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG;
    group = $GROUP;
    resource = $N3;
    threshold = $V3;
    msg = "Printer OK";
    status = "CLOSED";
END

#
# Sample mapping for "when System is not Reachable" event report
#
CLASS SNM_Host_Unreachable
  SELECT
    1: $AGENT_PROG = "ping" ;
    2: $GROUP = "reach" ;
    3: ATTR(=,"reachable.!="), VALUE(=, 1) ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG;
    group = $GROUP;
    resource = $N3;
    threshold = $V3;
    msg = "unreachable";
END

CLASS SNM_Host_Unreachable
  SELECT
    1: $AGENT_PROG = "ping" ;
    2: $GROUP = "reach" ;
    3: ATTR(=,"reachable.=="), VALUE(=, 1) ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG;
    group = $GROUP;
    resource = $N3;
    threshold = $V3;
    msg = "reachable";
    status = "CLOSED";
END

#
#  Component	: 50snmp_trap.cds
#
#  Description	: Mappings applied when translating generic SNMP traps 
#		  into T/EC Events.
#
#  Primary Author : Marc Foret / IT Masters Inc.
#
#  (C) COPYRIGHT Tivoli Systems Inc., 1996
#  All Rights Reserved
#

#############################################################################
#                                                                           #
#  SNMP-GENERIC TRAPS                                                       #
#                                                                           #
#############################################################################

CLASS Cold_Start
  SELECT
    1: $TRAP_TYPE = "coldStart" ;
  FETCH
    1: IPADDR($TARGET);
  MAP
    origin = $F1 ;
    date = $TRAP_RECEIVE_TIME ;
    msg = "Agent Up with  reinitialization";
END 

CLASS Warm_Start
  SELECT    
    1: $TRAP_TYPE = "warmStart" ;
  FETCH
    1: IPADDR($TARGET);
  MAP
    origin = $F1 ;
    date = $TRAP_RECEIVE_TIME ;
    msg = "Agent Up";
END

CLASS Link_Down
  SELECT
    1: $TRAP_TYPE = "linkDown" ;
    2: ATTR(=, "ifIndex");
  FETCH
    1: IPADDR($TARGET);
  MAP
    origin = $F1 ;
    date = $TRAP_RECEIVE_TIME ;
    sub_origin = $V2;
    msg = PRINTF( "Interface Down on %s", $V2);
END

CLASS Link_Up
  SELECT
    1: $TRAP_TYPE = "linkUp" ;
    2: ATTR(=, "ifIndex");
  FETCH
    1: IPADDR($TARGET);
  MAP
    origin = $F1 ;
    date = $TRAP_RECEIVE_TIME ;
    sub_origin = $V2;
    msg = PRINTF( "Interface Up on %s", $V2);
END

CLASS Authentication_Failure
  SELECT
    1: $TRAP_TYPE = "authenticationFailure" ;
  FETCH
    1: IPADDR($TARGET);
  MAP
    origin = $F1 ;
    date = $TRAP_RECEIVE_TIME ;
    msg = "Incorrect Community Name in a request";
END

CLASS EGP_Neighbor_Loss
  SELECT
    1: $TRAP_TYPE = "egpNeighborLoss" ;
  FETCH
    1: IPADDR($TARGET);
  MAP
    origin = $F1 ;
    msg = "EGP Neighbor Down";
    date = $TRAP_RECEIVE_TIME ;
END

#
#  Component	: 99snm_default.cds
#
#  Description	: Fall back mappings that can be applied for translation
# 		  of SunNet Manager Events into T/EC Events.
#
#  Primary Author : Marc Foret / IT Masters Inc.
#
#  (C) COPYRIGHT Tivoli Systems Inc., 1996
#  All Rights Reserved
#

#############################################################################
#                                                                           #
#  SNM DEFAULT TRAP REPORTS                                                 #
#                                                                           #
#############################################################################
 
CLASS SNM_SNMP_Trap
  SELECT
    1: $REPORT_TYPE = "TRAP" ;
    2: $AGENT_PROG = "snmp" ;
    3: $GROUP = "snmp-trap" ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    trap_sequence = $TRAP_SEQUENCE ;
    trap_receive_time = $TRAP_RECEIVE_TIME ;
    trap_version = $TRAP_VERSION ;
    trap_community = $TRAP_COMMUNITY ;
    trap_enterprise = $TRAP_ENTERPRISE ;
    trap_source_time = $TRAP_SOURCE_TIME ;
    trap_type = $TRAP_TYPE ;
    varbind_list = $VARBIND ;
END

CLASS SNM_DB_Trap
  SELECT
    1: $REPORT_TYPE = "TRAP" ;
    2: $AGENT_PROG = "db_mgr" ;
    3: $GROUP = "netmgt_db_config" ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    varbind_list = $VARBIND ;
END

CLASS SNM_Trap
  SELECT
    1: $REPORT_TYPE = "TRAP" ;
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    varbind_list = $VARBIND ;
END

#############################################################################
#                                                                           #
#  SNM DEFAULT EVENT REPORTS                                                #
#                                                                           #
#############################################################################

CLASS SNM_Event
  SELECT
    1: $REPORT_TYPE = "EVENT" ;
    2: ATTR(SUFFIX,".==");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG ;
    group = $GROUP ;
    sub_source = $K2;
    resource = $N2;
    threshold = $V2;
    msg = PRINTF("%s.%s:%s %s", $GROUP, $K2, $N2, $V2);
END

CLASS SNM_Event
  SELECT
    1: $REPORT_TYPE = "EVENT" ;
    2: ATTR(SUFFIX,".!=");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG ;
    group = $GROUP ;
    sub_source = $K2;
    resource = $N2;
    threshold = $V2;
    msg = PRINTF("%s.%s:%s %s", $GROUP, $K2, $N2, $V2);
END

CLASS SNM_Event
  SELECT
    1: $REPORT_TYPE = "EVENT" ;
    2: ATTR(SUFFIX,".>");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG ;
    group = $GROUP ;
    sub_source = $K2;
    resource = $N2;
    threshold = $V2;
    msg = PRINTF("%s.%s:%s %s", $GROUP, $K2, $N2, $V2);
END

CLASS SNM_Event
  SELECT
    1: $REPORT_TYPE = "EVENT" ;
    2: ATTR(SUFFIX,".<");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG ;
    group = $GROUP ;
    sub_source = $K2;
    resource = $N2;
    threshold = $V2;
    msg = PRINTF("%s.%s:%s %s", $GROUP, $K2, $N2, $V2);
END

CLASS SNM_Event
  SELECT
    1: $REPORT_TYPE = "EVENT" ;
    2: ATTR(SUFFIX,".>=");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG ;
    group = $GROUP ;
    sub_source = $K2;
    resource = $N2;
    threshold = $V2;
    msg = PRINTF("%s.%s:%s %s", $GROUP, $K2, $N2, $V2);
END

CLASS SNM_Event
  SELECT
    1: $REPORT_TYPE = "EVENT" ;
    2: ATTR(SUFFIX,".<=");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG ;
    group = $GROUP ;
    sub_source = $K2;
    resource = $N2;
    threshold = $V2;
    msg = PRINTF("%s.%s:%s %s", $GROUP, $K2, $N2, $V2);
    varbind_list = $VARBIND ;
END
CLASS SNM_Event
  SELECT
    1: $REPORT_TYPE = "EVENT" ;
    2: ATTR(SUFFIX,".+-");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG ;
    group = $GROUP ;
    sub_source = $K2;
    resource = $N2;
    threshold = $V2;
    msg = PRINTF("%s.%s:%s %s", $GROUP, $K2, $N2, $V2);
    varbind_list = $VARBIND ;
END
CLASS SNM_Event
  SELECT
    1: $REPORT_TYPE = "EVENT" ;
    2: ATTR(SUFFIX,".+=");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG ;
    group = $GROUP ;
    sub_source = $K2;
    resource = $N2;
    threshold = $V2;
    msg = PRINTF("%s.%s:%s %s", $GROUP, $K2, $N2, $V2);
    varbind_list = $VARBIND ;
END
CLASS SNM_Event
  SELECT
    1: $REPORT_TYPE = "EVENT" ;
    2: ATTR(SUFFIX,".-=");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG ;
    group = $GROUP ;
    sub_source = $K2;
    resource = $N2;
    threshold = $V2;
    msg = PRINTF("%s.%s:%s %s", $GROUP, $K2, $N2, $V2);
    varbind_list = $VARBIND ;
END
CLASS SNM_Event
  SELECT
    1: $REPORT_TYPE = "EVENT" ;
    2: ATTR(SUFFIX,".+<");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG ;
    group = $GROUP ;
    sub_source = $K2;
    resource = $N2;
    threshold = $V2;
    msg = PRINTF("%s.%s:%s %s", $GROUP, $K2, $N2, $V2);
    varbind_list = $VARBIND ;
END
CLASS SNM_Event
  SELECT
    1: $REPORT_TYPE = "EVENT" ;
    2: ATTR(SUFFIX,".+>");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG ;
    group = $GROUP ;
    sub_source = $K2;
    resource = $N2;
    threshold = $V2;
    msg = PRINTF("%s.%s:%s %s", $GROUP, $K2, $N2, $V2);
    varbind_list = $VARBIND ;
END

CLASS SNM_Event
  SELECT
    1: $REPORT_TYPE = "EVENT" ;
    2: ATTR(SUFFIX,".->");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG ;
    group = $GROUP ;
    sub_source = $K2;
    resource = $N2;
    threshold = $V2;
    msg = PRINTF("%s.%s:%s %s", $GROUP, $K2, $N2, $V2);
    varbind_list = $VARBIND ;
END

CLASS SNM_Event
  SELECT
    1: $REPORT_TYPE = "EVENT" ;
    2: ATTR(SUFFIX,".-<");
  FETCH
    1: IPADDR($TARGET);
    2: IPNAME($MANAGER_ADDR);
    3: IPNAME($AGENT_ADDR);
  MAP
    origin = $F1 ;
    adapter_host = $F2 ;
    agent_host = $F3 ;
    agent_prog = $AGENT_PROG ;
    group = $GROUP ;
    sub_source = $K2;
    resource = $N2;
    threshold = $V2;
    msg = PRINTF("%s.%s:%s %s", $GROUP, $K2, $N2, $V2);
    varbind_list = $VARBIND ;
END

